[Zope3-checkins] CVS: Zope3/src/zodb/storage/file - copy.py:1.5
Fred L. Drake, Jr.
fred@zope.com
Wed, 25 Jun 2003 10:54:16 -0400
Update of /cvs-repository/Zope3/src/zodb/storage/file
In directory cvs.zope.org:/tmp/cvs-serv31678
Modified Files:
copy.py
Log Message:
Fix another reference to _packt. Not sure if this is identical to
Jeremy's fix for this; Jeremy: please review.
=== Zope3/src/zodb/storage/file/copy.py 1.4 => 1.5 ===
--- Zope3/src/zodb/storage/file/copy.py:1.4 Mon May 19 11:03:47 2003
+++ Zope3/src/zodb/storage/file/copy.py Wed Jun 25 10:54:15 2003
@@ -32,7 +32,7 @@
_file -- file with earlier destination data
_tfile -- destination file for copied data
- _packt -- p64() representation of latest pack time
+ _pack_time -- p64() representation of latest pack time
_pos -- file pos of destination transaction
_tindex -- maps oid to data record file pos
_tvindex -- maps version name to data record file pos
@@ -55,8 +55,8 @@
return pos
if stop_at_pack:
# check the status field of the transaction header
- # XXX _packt seems to be either ZERO or None
- if h[16] == 'p' or _tid < self._packt:
+ # XXX _pack_time seems to be either ZERO or None
+ if h[16] == 'p' or _tid < self._pack_time:
break
raise UndoError(None, "Invalid transaction id")